26 #include "hip/hip_runtime.h"
33 typedef struct __attribute__((aligned(4))){
38 typedef __half2 half2;
68 __device__ __half2 __hadd2(
const __half2 a,
const __half2 b);
70 __device__ __half2 __hadd2_sat(
const __half2 a,
const __half2 b);
72 __device__ __half2 __hfma2(
const __half2 a,
const __half2 b,
const __half2 c);
74 __device__ __half2 __hfma2_sat(
const __half2 a,
const __half2 b,
const __half2 c);
76 __device__ __half2 __hmul2(
const __half2 a,
const __half2 b);
78 __device__ __half2 __hmul2_sat(
const __half2 a,
const __half2 b);
80 __device__ __half2 __hneq2(
const __half2 a);
82 __device__ __half2 __hsub2(
const __half2 a,
const __half2 b);
84 __device__ __half2 __hsub2_sat(
const __half2 a,
const __half2 b);
96 __device__
bool __hisinf(
const __half a);
98 __device__
bool __hisnan(
const __half a);
110 __device__
bool __hbeq2(
const __half2 a,
const __half2 b);
112 __device__
bool __hbge2(
const __half2 a,
const __half2 b);
114 __device__
bool __hbgt2(
const __half2 a,
const __half2 b);
116 __device__
bool __hble2(
const __half2 a,
const __half2 b);
118 __device__
bool __hblt2(
const __half2 a,
const __half2 b);
120 __device__
bool __hbne2(
const __half2 a,
const __half2 b);
122 __device__ __half2 __heq2(
const __half2 a,
const __half2 b);
124 __device__ __half2 __hge2(
const __half2 a,
const __half2 b);
126 __device__ __half2 __hgt2(
const __half2 a,
const __half2 b);
128 __device__ __half2 __hisnan2(
const __half2 a);
130 __device__ __half2 __hle2(
const __half2 a,
const __half2 b);
132 __device__ __half2 __hlt2(
const __half2 a,
const __half2 b);
134 __device__ __half2 __hne2(
const __half2 a,
const __half2 b);
141 __device__ __half2 __float22half2_rn(
const float2 a);
143 __device__
__half __float2half(
const float a);
145 __device__ __half2 __float2half2_rn(
const float a);
147 __device__ __half2 __floats2half2_rn(
const float a,
const float b);
149 __device__ float2 __half22float2(
const __half2 a);
151 __device__
float __half2float(
const __half a);
153 __device__ __half2 __half2half2(
const __half a);
155 __device__ __half2 __halves2half2(
const __half a,
const __half b);
157 __device__
float __high2float(
const __half2 a);
159 __device__
__half __high2half(
const __half2 a);
161 __device__ __half2 __high2half2(
const __half2 a);
163 __device__ __half2 __highs2half2(
const __half2 a,
const __half2 b);
165 __device__
float __low2float(
const __half2 a);
167 __device__
__half __low2half(
const __half2 a);
169 __device__ __half2 __low2half2(
const __half2 a);
171 __device__ __half2 __lows2half2(
const __half2 a,
const __half2 b);
173 __device__ __half2 __lowhigh2highlow(
const __half2 a);
175 __device__ __half2 __low2half2(
const __half2 a,
const __half2 b);
Definition: hip_fp16.h:28